@@ -3,7 +3,7 @@
 
 from .loss import *
 from .sequential import *
-from .switch_norm import *
+from .norm import *
 from .activation import *
 
 try:
