@@ -1,7 +1,12 @@
 # -*- coding: utf-8 -*-
 # @Author  : DevinYang(pistonyang@gmail.com)
 """This file should not be included in __init__"""
-__all__ = ['get_key', 'load_pyarrow', 'dumps_pyarrow', 'generate_lmdb_dataset', 'raw_reader']
+__all__ = [
+    'get_key',
+    'load_pyarrow',
+    'dumps_pyarrow',
+    'generate_lmdb_dataset',
+    'raw_reader']
 
 import lmdb
 import os
@@ -10,6 +15,7 @@ from torch.utils.data import DataLoader, Dataset
 from tqdm import tqdm
 from .utils import check_dir
 
+
 def get_key(index):
     return u'{}'.format(index).encode('ascii')
 
@@ -29,9 +35,17 @@ def load_pyarrow(buf):
     return pyarrow.deserialize(buf)
 
 
-def generate_lmdb_dataset(data_set: Dataset, save_dir: str, name: str,
-                          num_workers=0, max_size_rate=1.0, write_frequency=5000):
-    data_loader = DataLoader(data_set, num_workers=num_workers, collate_fn=lambda x: x)
+def generate_lmdb_dataset(
+        data_set: Dataset,
+        save_dir: str,
+        name: str,
+        num_workers=0,
+        max_size_rate=1.0,
+        write_frequency=5000):
+    data_loader = DataLoader(
+        data_set,
+        num_workers=num_workers,
+        collate_fn=lambda x: x)
     num_samples = len(data_set)
     check_dir(save_dir)
     lmdb_path = os.path.join(save_dir, '{}.lmdb'.format(name))
